{% extends "main.html" %} {% block styles %} {{ super() }}
{% endblock %} {% block content %}

# The Open-Source AgentOS

### Build production-ready AI agents in minutes, not months.

Quick Start

## The Open-Source Operating System for Agentic AI

#### Simple and intuitive syntax

#### Built-in conversation patterns

#### Seamless Human-AI collaboration

## Next Steps

#### Key concepts

Conversable Agent, Group Chat, Swarm, tools and more

#### Next level concepts

RAG, Code Execution, Complex Group Chats, and more

#### Use Cases

Customer Service, Travel Planning, and Game Design

#### Notebook Examples

In-depth and interactive notebooks for all things AG2

#### API Reference

Dig into all the important details

#### How to Contribute

Join us in making the most powerful multi-agent framework

## Popular resources

Foundation Capital Interview with Dr. Chi Wang
Learn AG2 on DeepLearningAI
{% endblock %}